# PyNM

<a href="https://travis-ci.org/ppsp-team/pynm"><img src="https://travis-ci.org/ppsp-team/pynm.svg?branch=master"></a> [![license](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://opensource.org/licenses/BSD-3-Clause)

Python implementation of Normative Modelling with Gaussian Processes, LOESS & Centiles approaches.

Original papers with Gaussian Processes (GP):
- [Marquand et al. Biological Psychiatry 2016](https://www.sciencedirect.com/science/article/pii/S0006322316000020)
- [Marquand et al. Molecular Psychiatry 2019](https://www.nature.com/articles/s41380-019-0441-1)

Example of use of the LOESS approach:
- [Lefebvre et al. Front. Neurosci. 2018](https://www.frontiersin.org/articles/10.3389/fnins.2018.00662/full)
- [Maruani et al. Front. Psychiatry 2019](https://www.frontiersin.org/articles/10.3389/fpsyt.2019.00011/full)

See also [Bethlehem et al. BioRxiv 2018](https://www.biorxiv.org/content/10.1101/252593v3) with R implementation [here](https://github.com/rb643/Normative_modeling).
